==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ApplicationGatewaySslCipherSuite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Ssl cipher suites enums.
 */
public enum class ApplicationGatewaySslCipherSuite(
    public val javaValue: com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite> {
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384),
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256),
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA),
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA),
    TLS_DHE_RSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_256_GCM_SHA384),
    TLS_DHE_RSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_128_GCM_SHA256),
    TLS_DHE_RSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_256_CBC_SHA),
    TLS_DHE_RSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_128_CBC_SHA),
    TLS_RSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_256_GCM_SHA384),
    TLS_RSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_128_GCM_SHA256),
    TLS_RSA_WITH_AES_256_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_256_CBC_SHA256),
    TLS_RSA_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_128_CBC_SHA256),
    TLS_RSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_256_CBC_SHA),
    TLS_RSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_128_CBC_SHA),
    TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384),
    TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256),
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384),
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256),
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA),
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA),
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_256_CBC_SHA256),
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_128_CBC_SHA256),
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_256_CBC_SHA),
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_128_CBC_SHA),
    TLS_RSA_WITH_3DES_EDE_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_3DES_EDE_CBC_SHA),
    TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA),
    TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256),
    TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite):
            ApplicationGatewaySslCipherSuite =
            ApplicationGatewaySslCipherSuite.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ApplicationGatewaySslCipherSuite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Ssl cipher suites enums.
 */
public enum class ApplicationGatewaySslCipherSuite(
    public val javaValue: com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite> {
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384),
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256),
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA),
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA),
    TLS_DHE_RSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_256_GCM_SHA384),
    TLS_DHE_RSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_128_GCM_SHA256),
    TLS_DHE_RSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_256_CBC_SHA),
    TLS_DHE_RSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_RSA_WITH_AES_128_CBC_SHA),
    TLS_RSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_256_GCM_SHA384),
    TLS_RSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_128_GCM_SHA256),
    TLS_RSA_WITH_AES_256_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_256_CBC_SHA256),
    TLS_RSA_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_128_CBC_SHA256),
    TLS_RSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_256_CBC_SHA),
    TLS_RSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_AES_128_CBC_SHA),
    TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384),
    TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256),
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384),
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256),
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA),
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA),
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_256_CBC_SHA256),
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_128_CBC_SHA256),
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_256_CBC_SHA),
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_AES_128_CBC_SHA),
    TLS_RSA_WITH_3DES_EDE_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_RSA_WITH_3DES_EDE_CBC_SHA),
    TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA),
    TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256),
    TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384(com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite.TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ApplicationGatewaySslCipherSuite): ApplicationGatewaySslCipherSuite =
            ApplicationGatewaySslCipherSuite.values().first { it.javaValue == javaType }
    }
}
